<?php

// +------------------------------------------------------------------+
// | Package Information                                              |
// +------------------------------------------------------------------+

/**
 * @package     EuropaCart
 * @subpackage  JFramework
 * @copyright   Copyright 1999-Present Kryptronic, Inc.  All rights reserved.
 * @link        http://www.kryptronic.com
 * @license     GNU/GPL
*/

// +------------------------------------------------------------------+
// | Package                                                          |
// +------------------------------------------------------------------+

// +--
// | No direct access.
// +--

defined('_JEXEC') or die ('Restricted access');

// +--
// | Import the plugin controller.
// +--

jimport( 'joomla.plugin.plugin' );

// +------------------------------------------------------------------+
// | Class Definition                                                 |
// +------------------------------------------------------------------+

class plgUserEuropaCart extends JPlugin {

// +--
// | EuropaCartCommon class variable.
// +--

var $EuropaCartCommon;

// +------------------------------------------------------------------+
// | Function: Constructor                                            |
// +------------------------------------------------------------------+

function plgUserEuropaCart(& $subject, $config) {

parent::__construct($subject, $config);

// +--
// | Load the EuropaCartCommon class from the EuropaCart_ObjectCache
// | so we can access common libraries.
// +--

global $EuropaCart_ObjectCache;

$this->EuropaCartCommon =& $EuropaCart_ObjectCache['EuropaCartCommon'];

} // End of function.

// +------------------------------------------------------------------+
// | Function: onBeforeStoreUser                                      |
// +------------------------------------------------------------------+

function onBeforeStoreUser($user, $isnew) {

// +--
// | Method is called before user data is stored in the database
// | 
// | param 	array		holds the old user data
// | param 	boolean		true if a new user is stored
// +--

// +--
// | Check the connection status.
// +--

global $EuropaCart_ConnectionActive;

if ((!(empty($EuropaCart_ConnectionActive))) || (empty($this->EuropaCartCommon))) {

     return;

} // End of if statement.

global $EuropaCart_ForceAddUser;

// +--
// | Build the XML request.
// +--

if (($isnew) && (empty($EuropaCart_ForceAddUser))) {

     $username = ''; if (!(empty($user['username']))) {$username = $user['username'];}
                     else {$username = (isset($_POST['username']) ? $_POST['username'] : '');
                     if (empty($username)) {$username = (isset($_GET['username']) ? $_GET['username'] : '');}}

     $email = '';    if (!(empty($user['email']))) {$email = $user['email'];}
                     else {$email = (isset($_POST['email']) ? $_POST['email'] : '');
                     if (empty($email)) {$email = (isset($_GET['email']) ? $_GET['email'] : '');}}

     $newuser = array('username' => $username,
                      'email'    => $email);

     $xmlrequest  = array('xml.0' => array('app.0'       => 'core',
                                           'namespace.0' => 'joomlasinglesignon',
                                           'params.0'    => $newuser));

     $xmlrequest['xml.0']['params.0']['method'] = 'CheckUserExists';

     $result = $this->EuropaCartCommon->sendXML($xmlrequest);

     if (!(empty($result['response']['exists']))) {

          $message = 'The username and/or password you entered is already 
                      associated with an account in another area of this website. 
                      Please use that area to login and access your account.';

          return JError::raiseError( 500, $message);

     } // End of if statement.

} // End of if statement.

// +--
// | Return.
// +--

return;

} // End of function.

// +------------------------------------------------------------------+
// | Function: onAfterStoreUser                                       |
// +------------------------------------------------------------------+

function onAfterStoreUser ($user, $isnew, $succes, $msg) {

// +--
// | Method is called after user data is stored in the database
// | 
// | param 	array		holds the new user data
// | param 	boolean		true if a new user is stored
// | param	boolean		true if user was succesfully stored in the database
// | param	string		message
// +--

// +--
// | Set admin status.
// +--

global $mainframe;

$admin_running = 0; if ($mainframe->isAdmin()) {$admin_running = 1;}

// +--
// | Check the connection status.
// +--

global $EuropaCart_ConnectionActive;

if ((!(empty($EuropaCart_ConnectionActive))) || (empty($this->EuropaCartCommon))) {

     return;

} // End of if statement.

// +--
// | Build the XML request.
// +--

if (!(empty($admin_running))) {$user['admin_running'] = 1;}

$my =& JFactory::getUser(); if ($my->get('id') == $user['id']) {$user['admin_running'] = 0;}

$xmlrequest  = array('xml.0' => array('app.0'       => 'core',
                                      'namespace.0' => 'joomlasinglesignon',
                                      'params.0'    => $user));

$xmlrequest['xml.0']['params.0']['method'] = 'onAfterStoreUser';

$result = $this->EuropaCartCommon->sendXML($xmlrequest);

// +--
// | Return true.
// +--

return true;

} // End of function.

// +------------------------------------------------------------------+
// | Function: onBeforeDeleteUser                                     |
// +------------------------------------------------------------------+

function onBeforeDeleteUser ($user) {

// +--
// | Method is called before user data is deleted from the database
// | 
// | param 	array		holds the user data
// +--

// +--
// | Return.
// +--

return;

} // End of function.

// +------------------------------------------------------------------+
// | Function: onAfterDeleteUser                                      |
// +------------------------------------------------------------------+

function onAfterDeleteUser($user, $succes, $msg) {

// +--
// | Method is called after user data is deleted from the database
// | 
// | param 	array		holds the user data
// | param	boolean		true if user was succesfully stored in the database
// | param	string		message
// +--

// +--
// | Check the connection status.
// +--

global $EuropaCart_ConnectionActive;

if ((!(empty($EuropaCart_ConnectionActive))) || (empty($this->EuropaCartCommon))) {

     return;

} // End of if statement.

// +--
// | Build the XML request.
// +--

$xmlrequest  = array('xml.0' => array('app.0'       => 'core',
                                      'namespace.0' => 'joomlasinglesignon',
                                      'params.0'    => $user));

$xmlrequest['xml.0']['params.0']['method'] = 'onAfterDeleteUser';

$result = $this->EuropaCartCommon->sendXML($xmlrequest);

// +--
// | Return true.
// +--

return true;

} // End of function.

// +------------------------------------------------------------------+
// | Function: onLoginUser                                            |
// +------------------------------------------------------------------+

function onLoginUser($user, $options) {

// +--
// | This method should handle any login logic and report back to the subject
// | 
// | access	public
// | param 	array 	holds the user data
// | param 	array    extra options
// | return	boolean	True on success
// | since	1.5
// +--

// +--
// | Check the connection status.
// +--

global $EuropaCart_ConnectionActive;

if ((!(empty($EuropaCart_ConnectionActive))) || (empty($this->EuropaCartCommon))) {

     return;

} // End of if statement.

// +--
// | Build the XML request.
// +--

$xmlrequest  = array('xml.0' => array('app.0'       => 'core',
                                      'namespace.0' => 'joomlasinglesignon',
                                      'params.0'    => $user));

$xmlrequest['xml.0']['params.0']['method'] = 'onLoginUser';

$result = $this->EuropaCartCommon->sendXML($xmlrequest);

// +--
// | Return true.
// +--

return true;

} // End of function.

// +------------------------------------------------------------------+
// | Function: onLogoutUser                                           |
// +------------------------------------------------------------------+

function onLogoutUser ($user) {

// +--
// | This method should handle any logout logic and report back to the subject
// | 
// | access public
// | param array holds the user data
// | return boolean True on success
// | since 1.5
// +--

// +--
// | Check the connection status.
// +--

global $EuropaCart_ConnectionActive;

if ((!(empty($EuropaCart_ConnectionActive))) || (empty($this->EuropaCartCommon))) {

     return;

} // End of if statement.

// +--
// | Build the XML request.
// +--

$xmlrequest  = array('xml.0' => array('app.0'       => 'core',
                                      'namespace.0' => 'joomlasinglesignon',
                                      'params.0'    => $user));

$xmlrequest['xml.0']['params.0']['method'] = 'onLogoutUser';

$result = $this->EuropaCartCommon->sendXML($xmlrequest);

// +--
// | Return true.
// +--

return true;

} // End of function.

// +------------------------------------------------------------------+
// | End of Class                                                     |
// +------------------------------------------------------------------+

} // End of class.

// +------------------------------------------------------------------+
// | End Of File                                                      |
// +------------------------------------------------------------------+

?>